Update RCCL-tests in examples folder (#261)

- Create a local copy for ROCm/rccl-tests for our examples.
- Update argument parsing to no longer use getopt_long.
- Workaround for Dyninst instrumentation.

---------

Co-authored-by: David Galiffi <David.Galiffi@amd.com>

[ROCm/rocprofiler-systems commit: 4e5029221b]
This commit is contained in:
Pranjal Swarup
2025-06-27 11:44:13 -04:00
committed by GitHub
parent 0c91a0d8ed
commit 0497b7934f
26 changed files with 7330 additions and 13 deletions
@@ -0,0 +1,131 @@
/*************************************************************************
* Copyright (c) 2016-2022, NVIDIA CORPORATION. All rights reserved.
* Modifications Copyright (c) 2019-2022 Advanced Micro Devices, Inc. All rights reserved.
*
* See LICENSE.txt for license information
************************************************************************/
#include "common.h"
#include "cuda_runtime.h"
void
ReduceScatterGetCollByteCount(size_t* sendcount, size_t* recvcount, size_t* paramcount,
size_t* sendInplaceOffset, size_t* recvInplaceOffset,
size_t count, size_t eltSize, int nranks)
{
size_t base = (count / nranks) & -(16 / eltSize);
*sendcount = base * nranks;
*recvcount = base;
*sendInplaceOffset = 0;
*recvInplaceOffset = base;
*paramcount = base;
}
testResult_t
ReduceScatterInitData(struct threadArgs* args, ncclDataType_t type, ncclRedOp_t op,
int root, int rep, int in_place)
{
size_t sendcount = args->sendBytes / wordSize(type);
size_t recvcount = args->expectedBytes / wordSize(type);
int nranks = args->nProcs * args->nThreads * args->nGpus;
for(int i = 0; i < args->nGpus; i++)
{
CUDACHECK(cudaSetDevice(args->gpus[i]));
int rank = ((args->proc * args->nThreads + args->thread) * args->nGpus + i);
CUDACHECK(cudaMemset(args->recvbuffs[i], 0, args->expectedBytes));
void* data = in_place ? args->recvbuffs[i] : args->sendbuffs[i];
TESTCHECK(InitData(data, sendcount, 0, type, op, rep, nranks, rank));
CUDACHECK(cudaMemcpy(args->expected[i], args->recvbuffs[i], args->expectedBytes,
cudaMemcpyDefault));
TESTCHECK(InitDataReduce(args->expected[i], recvcount, rank * recvcount, type, op,
rep, nranks));
CUDACHECK(cudaDeviceSynchronize());
}
return testSuccess;
}
void
ReduceScatterGetBw(size_t count, int typesize, double sec, double* algBw, double* busBw,
int nranks)
{
double baseBw = (double) (count * typesize * nranks) / 1.0E9 / sec;
*algBw = baseBw;
double factor = ((double) (nranks - 1)) / ((double) nranks);
*busBw = baseBw * factor;
}
testResult_t
ReduceScatterRunColl(void* sendbuff, void* recvbuff, size_t count, ncclDataType_t type,
ncclRedOp_t op, int root, ncclComm_t comm, cudaStream_t stream)
{
NCCLCHECK(ncclReduceScatter(sendbuff, recvbuff, count, type, op, comm, stream));
return testSuccess;
}
struct testColl reduceScatterTest = { "ReduceScatter", ReduceScatterGetCollByteCount,
ReduceScatterInitData, ReduceScatterGetBw,
ReduceScatterRunColl };
void
ReduceScatterGetBuffSize(size_t* sendcount, size_t* recvcount, size_t count, int nranks)
{
size_t paramcount, sendInplaceOffset, recvInplaceOffset;
ReduceScatterGetCollByteCount(sendcount, recvcount, &paramcount, &sendInplaceOffset,
&recvInplaceOffset, count, /*eltSize=*/1, nranks);
}
testResult_t
ReduceScatterRunTest(struct threadArgs* args, int root, ncclDataType_t type,
const char* typeName, ncclRedOp_t op, const char* opName)
{
args->collTest = &reduceScatterTest;
ncclDataType_t* run_types;
ncclRedOp_t* run_ops;
const char ** run_typenames, **run_opnames;
int type_count, op_count;
if((int) type != -1)
{
type_count = 1;
run_types = &type;
run_typenames = &typeName;
}
else
{
type_count = test_typenum;
run_types = test_types;
run_typenames = test_typenames;
}
if((int) op != -1)
{
run_ops = &op;
run_opnames = &opName;
op_count = 1;
}
else
{
op_count = test_opnum;
run_ops = test_ops;
run_opnames = test_opnames;
}
for(int i = 0; i < type_count; i++)
{
for(int j = 0; j < op_count; j++)
{
#if defined(RCCL_FLOAT8)
if((run_types[i] == ncclFp8E4M3 || run_types[i] == ncclFp8E5M2) &&
run_ops[j] == ncclProd)
continue;
#endif
TESTCHECK(TimeTest(args, run_types[i], run_typenames[i], run_ops[j],
run_opnames[j], -1));
}
}
return testSuccess;
}
struct testEngine ncclTestEngine = { ReduceScatterGetBuffSize, ReduceScatterRunTest };